@@ -1,15 +1,15 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: UTF-8 -*-
 ###########################################################################
-# Eole NG - 2007  
+# Eole NG - 2007
 # Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
 # Licence CeCill  cf /root/LicenceEole.txt
-# eole@ac-dijon.fr 
-#  
+# eole@ac-dijon.fr
+#
 # add_user.py
-#  
+#
 # Utilitaire de création d'utilisateurs LDAP pour zephir
-#       
+#
 ###########################################################################
 
 import getpass
@@ -18,7 +18,7 @@ from zephir.utils.ldap_user import add_user, encrypt_passwd
 
 if __name__ == '__main__':
     # on demande le nom et mot de passe du nouvel utilisateur
-    login = raw_input("nom de connexion du nouvel utilisateur : ")
+    login = input("nom de connexion du nouvel utilisateur : ")
     # mot de passe du nouvel utilisateur
     pass_ok = 0
     while pass_ok == 0:
